Module: Upwork
- Defined in:
- lib/upwork/api.rb,
lib/upwork/api/client.rb,
lib/upwork/api/config.rb,
lib/upwork/api/logger.rb,
lib/upwork/api/version.rb,
lib/upwork/api/routers/auth.rb,
lib/upwork/api/routers/hr/jobs.rb,
lib/upwork/api/routers/hr/roles.rb,
lib/upwork/api/routers/messages.rb,
lib/upwork/api/routers/metadata.rb,
lib/upwork/api/routers/payments.rb,
lib/upwork/api/routers/snapshot.rb,
lib/upwork/api/routers/workdays.rb,
lib/upwork/api/routers/workdiary.rb,
lib/upwork/api/routers/jobs/search.rb,
lib/upwork/api/routers/hr/contracts.rb,
lib/upwork/api/routers/jobs/profile.rb,
lib/upwork/api/routers/reports/time.rb,
lib/upwork/api/routers/hr/interviews.rb,
lib/upwork/api/routers/hr/milestones.rb,
lib/upwork/api/routers/hr/engagements.rb,
lib/upwork/api/routers/hr/submissions.rb,
lib/upwork/api/routers/activities/team.rb,
lib/upwork/api/routers/hr/clients/offers.rb,
lib/upwork/api/routers/freelancers/search.rb,
lib/upwork/api/routers/organization/teams.rb,
lib/upwork/api/routers/organization/users.rb,
lib/upwork/api/routers/freelancers/profile.rb,
lib/upwork/api/routers/activities/engagement.rb,
lib/upwork/api/routers/hr/freelancers/offers.rb,
lib/upwork/api/routers/organization/companies.rb,
lib/upwork/api/routers/hr/clients/applications.rb,
lib/upwork/api/routers/reports/finance/accounts.rb,
lib/upwork/api/routers/reports/finance/billings.rb,
lib/upwork/api/routers/reports/finance/earnings.rb,
lib/upwork/api/routers/hr/freelancers/applications.rb
Overview
Licensed under the Upwork's API Terms of Use; you may not use this file except in compliance with the Terms.
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
- Author
Maksym Novozhylov ([email protected])
- Copyright
Copyright 2014(c) Upwork.com
- License
See LICENSE.txt and TOS - https://developers.upwork.com/api-tos.html
Defined Under Namespace
Modules: Api